@@ -297,6 +297,7 @@ class Filesystems(object):
             fstab = self.getByDevice(device)
         else:
             fstab = self.getBySourceDevice(device)
+
         if fstab == None:
             if options == None:
                 options = "defaults"
@@ -376,13 +377,13 @@ class Filesystems(object):
             if type.startswith("ext"):
                 options = " -b 4096 -E stride=%d,stripe-width=%d" % (stride, strideWidth)
             if type.startswith("xfs"):
-                options = " d su=%s -d sw=%s" % (md.chunkSize.lower(), numDevs)
+                options = " -d su=%s -d sw=%s" % (md.chunkSize.lower(), numDevs)
         mkfs = 'mkfs.%s%s %s' % (type, options, device)
         out = run(mkfs)
         if out.rc == 0:
             return True
         else:
-            raise FilesytemException("error while formation %s. STDOUT: %s STDERR: %s" % (device, out.stdout, out.stderr))
+            raise FilesytemException("error while formation %s. STDOUT: %s STDERR: %s CMD: %s" % (device, out.stdout, out.stderr, mkfs))
 
 
     @classmethod
